summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmpigmentedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmpigmentedit.h')
-rw-r--r--kpovmodeler/pmpigmentedit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmpigmentedit.h b/kpovmodeler/pmpigmentedit.h
index 578bdb46..82ca91e1 100644
--- a/kpovmodeler/pmpigmentedit.h
+++ b/kpovmodeler/pmpigmentedit.h
@@ -39,9 +39,9 @@ class PMPigmentEdit : public PMTextureBaseEdit
typedef PMTextureBaseEdit Base;
public:
/**
* Creates a PMPigmentEdit with tqparent and name
*/
- PMPigmentEdit( TQWidget* tqparent, const char* name = 0 );
+ PMPigmentEdit( TQWidget* parent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -39,9 +39,9 @@ class PMPigmentEdit : public PMTextureBaseEdit
public:
/**
- * Creates a PMPigmentEdit with tqparent and name
+ * Creates a PMPigmentEdit with parent and name
*/